summaryrefslogtreecommitdiff
path: root/lib/CodeGen/OcamlGC.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'lib/CodeGen/OcamlGC.cpp')
-rw-r--r--lib/CodeGen/OcamlGC.cpp27
1 files changed, 9 insertions, 18 deletions
diff --git a/lib/CodeGen/OcamlGC.cpp b/lib/CodeGen/OcamlGC.cpp
index 88499cbd66..0b90444406 100644
--- a/lib/CodeGen/OcamlGC.cpp
+++ b/lib/CodeGen/OcamlGC.cpp
@@ -1,4 +1,4 @@
//===-- OcamlCollector.cpp - Ocaml frametable emitter ---------------------===//
//
// The LLVM Compiler Infrastructure
//
@@ -9,38 +9,29 @@
//
// This file implements lowering for the llvm.gc* intrinsics compatible with
// Objective Caml 3.10.0, which uses a liveness-accurate static stack map.
+//
+// The frametable emitter is in OcamlGCPrinter.cpp.
//
//===----------------------------------------------------------------------===//
#include "llvm/CodeGen/GCs.h"
-#include "llvm/CodeGen/AsmPrinter.h"
#include "llvm/CodeGen/GCStrategy.h"
-#include "llvm/Module.h"
-#include "llvm/Target/TargetAsmInfo.h"
-#include "llvm/Target/TargetData.h"
-#include "llvm/Target/TargetMachine.h"
using namespace llvm;
namespace {
-
- class VISIBILITY_HIDDEN OcamlCollector : public Collector {
+ class VISIBILITY_HIDDEN OcamlGC : public GCStrategy {
public:
- OcamlCollector();
+ OcamlGC();
};
-
}
-static CollectorRegistry::Add<OcamlCollector>
-X("ocaml", "ocaml 3.10-compatible collector");
-
-// -----------------------------------------------------------------------------
+static GCRegistry::Add<OcamlGC>
+X("ocaml", "ocaml 3.10-compatible GC");
-Collector *llvm::createOcamlCollector() {
- return new OcamlCollector();
-}
+void llvm::linkOcamlGC() { }
-OcamlCollector::OcamlCollector() {
+OcamlGC::OcamlGC() {
NeededSafePoints = 1 << GC::PostCall;
UsesMetadata = true;
}
@@ -1,4 +1,4 @@
-//===-- OcamlCollector.cpp - Ocaml frametable emitter ---------------------===//
+//===-- OcamlGC.cpp - Ocaml frametable GC strategy ------------------------===//
//
// The LLVM Compiler Infrastructure